<!--next-version-placeholder-->

## v0.3.6 (2025-12-28)

### Bug Fixes

- Update title in README to reflect current position
  ([`07d3681`](https://github.com/entelecheia/entelecheia/commit/07d368135010a05e082d8fd9cbe8842f277c79b2))

### Chores

- Add uv installation step to GitHub Actions release workflow
  ([`ff6bd07`](https://github.com/entelecheia/entelecheia/commit/ff6bd07822b831c5d9ba5cef8502467c3a9776bb))

- Modify build command to include uv installation
  ([`ec823c1`](https://github.com/entelecheia/entelecheia/commit/ec823c1f976be0f2ea35858f6b83a96835458c7b))

- Remove GitHub profile hit counter from README
  ([`b8fb2a6`](https://github.com/entelecheia/entelecheia/commit/b8fb2a65d2e9d6a7f1146b8022113e2ca6ce52bf))

- Remove obsolete configuration and task files, update project structure
  ([`407432c`](https://github.com/entelecheia/entelecheia/commit/407432c84cc0e621464e8f11a4b11ce373386a89))

- Update course links in README.md
  ([`1b5c673`](https://github.com/entelecheia/entelecheia/commit/1b5c6739dbf3a10d485ec868b8610c9a40cc359a))

- Update dependency installation commands and exclude .venv in configuration
  ([`5f97576`](https://github.com/entelecheia/entelecheia/commit/5f975767efd296d5b2ad8ed442d3977dd7bac448))

- Update GitHub Actions workflow to use uv for dependency installation and linting
  ([`baf6696`](https://github.com/entelecheia/entelecheia/commit/baf6696d74404e0851ab514da881c9fc7014536b))

- Update job title in README.md
  ([`3faac91`](https://github.com/entelecheia/entelecheia/commit/3faac91478c856c4c8997f0ebfc6d626cfcdd194))

- Update poetry lock
  ([`a8cb573`](https://github.com/entelecheia/entelecheia/commit/a8cb573e8b98ebbddf6ae0238d8e7bffda35bcac))

- Update README.md
  ([`7e1da00`](https://github.com/entelecheia/entelecheia/commit/7e1da00745112b9f02aba55cd5f693ea218d322d))

- Update STAI and lecture links in README.md
  ([`1a68890`](https://github.com/entelecheia/entelecheia/commit/1a6889044aee3c1aeafdf3938f0c5997b33b76fa))

- **deps**: Bump actions/checkout from 4 to 5
  ([`863776a`](https://github.com/entelecheia/entelecheia/commit/863776a867637242b5528c47dd2c744a30cfd20d))

- **deps**: Bump actions/checkout from 5 to 6
  ([`bb74479`](https://github.com/entelecheia/entelecheia/commit/bb7447929c4ed6e6228cd44573b2ac1f6ebd49c8))

- **deps**: Bump actions/setup-python from 5 to 6
  ([`768be3b`](https://github.com/entelecheia/entelecheia/commit/768be3b2daaa05764fcd8cabf8b0074df703c62a))

- **deps**: Bump jupyter-book from 1.0.3 to 1.0.4 (#133)
  ([#133](https://github.com/entelecheia/entelecheia/pull/133),
  [`c3004be`](https://github.com/entelecheia/entelecheia/commit/c3004be08cddde04582a22155791b7004ef261c5))

- **deps**: Bump jupyter-book from 1.0.4 to 1.0.4.post1 (#142)
  ([#142](https://github.com/entelecheia/entelecheia/pull/142),
  [`682a1a3`](https://github.com/entelecheia/entelecheia/commit/682a1a3bb6f4d6668092bc6a62313f9d74ac99bd))

- **deps**: Bump python-semantic-release/publish-action
  ([`a004234`](https://github.com/entelecheia/entelecheia/commit/a004234845ea2b82254ad34c350e9cb7a91f550a))

- **deps**: Bump python-semantic-release/publish-action
  ([`8bb0e6a`](https://github.com/entelecheia/entelecheia/commit/8bb0e6ae92d1455758ccd7419a2aee34f9f082dd))

- **deps**: Bump python-semantic-release/publish-action
  ([`42a2b86`](https://github.com/entelecheia/entelecheia/commit/42a2b86e3be10ced7e7741c290b6be9373d4d591))

- **deps**: Bump python-semantic-release/publish-action
  ([`06eea0c`](https://github.com/entelecheia/entelecheia/commit/06eea0c205639d774836e0646a2a361a26c7ee46))

- **deps**: Bump python-semantic-release/publish-action
  ([`ae8276a`](https://github.com/entelecheia/entelecheia/commit/ae8276ada57256928478eaa6a5e6c1d028300fea))

- **deps**: Bump python-semantic-release/publish-action
  ([`f249db7`](https://github.com/entelecheia/entelecheia/commit/f249db7685fa20ece3bd120f60eb3ae2bc16a2d6))

- **deps**: Bump python-semantic-release/publish-action (#120)
  ([#120](https://github.com/entelecheia/entelecheia/pull/120),
  [`bec95ed`](https://github.com/entelecheia/entelecheia/commit/bec95ed9d68c84cb68d35fd227f05f08bb75d5cb))

- **deps**: Bump python-semantic-release/publish-action (#122)
  ([#122](https://github.com/entelecheia/entelecheia/pull/122),
  [`1562046`](https://github.com/entelecheia/entelecheia/commit/156204690864d77fed0870784ed5405e593317bd))

- **deps**: Bump python-semantic-release/publish-action (#128)
  ([#128](https://github.com/entelecheia/entelecheia/pull/128),
  [`35a1aba`](https://github.com/entelecheia/entelecheia/commit/35a1abaa82b81b0a0fa43f6602a0fec16ffc8182))

- **deps**: Bump python-semantic-release/publish-action (#130)
  ([#130](https://github.com/entelecheia/entelecheia/pull/130),
  [`276c02f`](https://github.com/entelecheia/entelecheia/commit/276c02f0f12a06ec8244288e4f5ebee14bef3619))

- **deps**: Bump python-semantic-release/publish-action (#131)
  ([#131](https://github.com/entelecheia/entelecheia/pull/131),
  [`d1854e5`](https://github.com/entelecheia/entelecheia/commit/d1854e5237b5614b6d2dfdc46b482b9f8d6fccd0))

- **deps**: Bump python-semantic-release/publish-action (#134)
  ([#134](https://github.com/entelecheia/entelecheia/pull/134),
  [`1ee3d52`](https://github.com/entelecheia/entelecheia/commit/1ee3d52971b1e6db7facc43c7ed3914ee609f416))

- **deps**: Bump python-semantic-release/publish-action (#136)
  ([#136](https://github.com/entelecheia/entelecheia/pull/136),
  [`ac1cf9c`](https://github.com/entelecheia/entelecheia/commit/ac1cf9cc018188c34d1edd83bae54332edcfeb3d))

- **deps**: Bump python-semantic-release/publish-action (#138)
  ([#138](https://github.com/entelecheia/entelecheia/pull/138),
  [`f216df3`](https://github.com/entelecheia/entelecheia/commit/f216df3ff62eb6f428cb3d61ef625fd45b0faec3))

- **deps**: Bump python-semantic-release/publish-action (#140)
  ([#140](https://github.com/entelecheia/entelecheia/pull/140),
  [`e93dc52`](https://github.com/entelecheia/entelecheia/commit/e93dc52353c36b4c597df75ffff248485ec6cd25))

- **deps**: Bump python-semantic-release/python-semantic-release
  ([`7486363`](https://github.com/entelecheia/entelecheia/commit/74863634bb62e3cb2aa15a7a21688a0ceb396ccc))

- **deps**: Bump python-semantic-release/python-semantic-release
  ([`6fd612c`](https://github.com/entelecheia/entelecheia/commit/6fd612c8173ce284448a19bd7810fc1cd9b6dae1))

- **deps**: Bump python-semantic-release/python-semantic-release
  ([`0e097be`](https://github.com/entelecheia/entelecheia/commit/0e097be44ff50ca3e42bcd8a2e0f72153c9fa144))

- **deps**: Bump python-semantic-release/python-semantic-release
  ([`d704a2b`](https://github.com/entelecheia/entelecheia/commit/d704a2b9a12df61ab1ca339b9bd4888ce7e1f082))

- **deps**: Bump python-semantic-release/python-semantic-release (#119)
  ([#119](https://github.com/entelecheia/entelecheia/pull/119),
  [`4439738`](https://github.com/entelecheia/entelecheia/commit/4439738417f62cfc146313b7b7e1d1ad274cb0aa))

- **deps**: Bump python-semantic-release/python-semantic-release (#121)
  ([#121](https://github.com/entelecheia/entelecheia/pull/121),
  [`86ad33f`](https://github.com/entelecheia/entelecheia/commit/86ad33f695f9b5a9ccfbc6e904d7f5bb598c49d0))

- **deps**: Bump python-semantic-release/python-semantic-release (#127)
  ([#127](https://github.com/entelecheia/entelecheia/pull/127),
  [`d366c69`](https://github.com/entelecheia/entelecheia/commit/d366c692b437eb8f6e4dcfb49595c4ed94ea74dc))

- **deps**: Bump python-semantic-release/python-semantic-release (#129)
  ([#129](https://github.com/entelecheia/entelecheia/pull/129),
  [`be3c6e8`](https://github.com/entelecheia/entelecheia/commit/be3c6e8d1a97ad247272b7fedbdb02380cc4bcba))

- **deps**: Bump python-semantic-release/python-semantic-release (#132)
  ([#132](https://github.com/entelecheia/entelecheia/pull/132),
  [`d3c80c4`](https://github.com/entelecheia/entelecheia/commit/d3c80c4b1ae3110e0015774cd1fd679750772adc))

- **deps**: Bump python-semantic-release/python-semantic-release (#135)
  ([#135](https://github.com/entelecheia/entelecheia/pull/135),
  [`6768589`](https://github.com/entelecheia/entelecheia/commit/676858951f147b8cef54ae05b114a1a7c99f0d25))

- **deps**: Bump python-semantic-release/python-semantic-release (#137)
  ([#137](https://github.com/entelecheia/entelecheia/pull/137),
  [`904b134`](https://github.com/entelecheia/entelecheia/commit/904b1341b5971bf172e2a688458a5fbabd198487))

- **deps**: Bump python-semantic-release/python-semantic-release (#139)
  ([#139](https://github.com/entelecheia/entelecheia/pull/139),
  [`932d73a`](https://github.com/entelecheia/entelecheia/commit/932d73a9060d595645cb0a8d9ce89071a7ff93f1))

- **deps**: Bump python-semantic-release/python-semantic-release (#141)
  ([#141](https://github.com/entelecheia/entelecheia/pull/141),
  [`01cb45f`](https://github.com/entelecheia/entelecheia/commit/01cb45f05381364823ba9d2da35c3ba05780f310))

### Documentation

- Fix typo in consortium name in README
  ([`174979b`](https://github.com/entelecheia/entelecheia/commit/174979ba52c8205606233b454222cc7f262c59d2))

- Remove co-authors from research mention in README
  ([`7fa4647`](https://github.com/entelecheia/entelecheia/commit/7fa4647d5aea29c834ff4ff0201226e478deb770))

- Update personal introduction and research focus in README
  ([`347ccd8`](https://github.com/entelecheia/entelecheia/commit/347ccd8c6085e217178c996f95827caad2a3a451))


## v0.3.5 (2024-11-25)

### Bug Fixes

- Update pyproject.toml for semantic release configuration and dependency versions
  ([`0ec0f04`](https://github.com/entelecheia/entelecheia/commit/0ec0f049404ea1b2b04ca8273077f63573005f28))

- Update release workflow to trigger on push and streamline release steps
  ([`08d5d64`](https://github.com/entelecheia/entelecheia/commit/08d5d644166ab456254516d11620e8b2c592b4bf))

### Chores

- **deps**: Bump codecov/codecov-action from 4 to 5
  ([`3d8a4b8`](https://github.com/entelecheia/entelecheia/commit/3d8a4b819fde0422b9aaf674340eac0a5067a2df))

Bumps [codecov/codecov-action](https://github.com/codecov/codecov-action) from 4 to 5. - [Release
  notes](https://github.com/codecov/codecov-action/releases) -
  [Changelog](https://github.com/codecov/codecov-action/blob/main/CHANGELOG.md) -
  [Commits](https://github.com/codecov/codecov-action/compare/v4...v5)

--- updated-dependencies: - dependency-name: codecov/codecov-action dependency-type:
  direct:production update-type: version-update:semver-major ...

Signed-off-by: dependabot[bot] <support@github.com>

- **deps**: Bump hyfi from 1.36.4 to 1.37.0
  ([`dd4dd60`](https://github.com/entelecheia/entelecheia/commit/dd4dd60ef3ee56023e4752ebbf103d616213c384))

Bumps [hyfi](https://github.com/entelecheia/hyfi) from 1.36.4 to 1.37.0. - [Release
  notes](https://github.com/entelecheia/hyfi/releases) -
  [Changelog](https://github.com/entelecheia/hyfi/blob/main/CHANGELOG.md) -
  [Commits](https://github.com/entelecheia/hyfi/compare/v1.36.4...v1.37.0)

--- updated-dependencies: - dependency-name: hyfi dependency-type: direct:production update-type:
  version-update:semver-minor ...

Signed-off-by: dependabot[bot] <support@github.com>

- **deps**: Bump jupyter-book from 1.0.2 to 1.0.3
  ([`82f7a55`](https://github.com/entelecheia/entelecheia/commit/82f7a55d86111f6c439f4ca359beab782be85234))

Bumps [jupyter-book](https://github.com/executablebooks/jupyter-book) from 1.0.2 to 1.0.3. -
  [Release notes](https://github.com/executablebooks/jupyter-book/releases) -
  [Changelog](https://github.com/jupyter-book/jupyter-book/blob/main/CHANGELOG.md) -
  [Commits](https://github.com/executablebooks/jupyter-book/compare/v1.0.2...v1.0.3)

--- updated-dependencies: - dependency-name: jupyter-book dependency-type: direct:production
  update-type: version-update:semver-patch ...

Signed-off-by: dependabot[bot] <support@github.com>

### Documentation

- Update personal introduction and research focus in README.md
  ([`fb7536c`](https://github.com/entelecheia/entelecheia/commit/fb7536c285aa3ae975a9cb3eb112d7e4511a4f82))


## v0.3.4 (2024-09-14)

### Fix

* **docs:** Update documentation URLs to youngjoon-lee.com ([`f70c640`](https://github.com/entelecheia/entelecheia/commit/f70c6403cdc854d8875b266c0b4aa33e9320c95c))
* **docs:** Update repository URL in README.md ([`ea0e505`](https://github.com/entelecheia/entelecheia/commit/ea0e50504ca9c53ee207b793d6d3077fb9145aa4))

## v0.3.3 (2024-07-20)

### Fix

* **dependencies:** Update multiple dependencies in poetry.lock ([`7099ee4`](https://github.com/entelecheia/entelecheia/commit/7099ee480790bb9238029fa5d4c5e15ec2f9f96e))

## v0.3.2 (2024-04-21)

### Fix

* **docs:** Update GitHub Stats link in README.md ([`1ced68b`](https://github.com/entelecheia/entelecheia/commit/1ced68b2a47c9cc8cb0c3653d114d1e1e2f5fba8))

## v0.3.1 (2024-03-25)

### Fix

* **entelecheia:** Remove unused function open_homepage and update about yaml configuration ([`0f34a67`](https://github.com/entelecheia/entelecheia/commit/0f34a6701c1e60896da953c30474883597c9c840))
* **dependencies:** Update hyfi version to 1.36.3 ([`8bcc3dd`](https://github.com/entelecheia/entelecheia/commit/8bcc3dd782bd619a7fd106dad5c7a29cdf82b8b7))

## v0.3.0 (2024-03-23)

### Feature

* **entelecheia:** Add target field in about page manifest ([`6d53342`](https://github.com/entelecheia/entelecheia/commit/6d533425bfe2e8cae91571881ccc35f04be92e61))
* **init:** Add open_homepage function ([`f02a063`](https://github.com/entelecheia/entelecheia/commit/f02a06358f56cee7503f313b1901c6cd46f0f72e))

### Fix

* **pyproject:** Upgrade Python version to ^3.9, hyfi to ^1.36.1 ([`75b158f`](https://github.com/entelecheia/entelecheia/commit/75b158f0ddfb9d0bcfa9c6c16021ac55bdb89a72))

## v0.2.16 (2023-07-30)
### Fix
* **dependencies:** Upgrade hyfi to 1.12.5 ([`91e13e3`](https://github.com/entelecheia/entelecheia/commit/91e13e3ff6537e61cc4c5985d67603e4cf87f23e))

## v0.2.15 (2023-07-26)
### Fix
* **entelecheia:** Change initialization methods for HyFI and logging ([`79fd6eb`](https://github.com/entelecheia/entelecheia/commit/79fd6eb8df7117a4f9e0abf31a0c2c718c2f6012))

## v0.2.14 (2023-07-23)
### Fix
* **entelecheia:** Change initialization of HyFI object and its logger ([`1c236ec`](https://github.com/entelecheia/entelecheia/commit/1c236eca021b13649554ff9065cc75935e5088b1))
* **entelecheia:** Replace hydra_main with hyfi_main ([`4bfaa38`](https://github.com/entelecheia/entelecheia/commit/4bfaa380e974ffcc03c4f00fcef49f88a594497b))
* **dependencies:** Update hyfi to 1.8.1, limit black version to 23.3.0 ([`1632eb9`](https://github.com/entelecheia/entelecheia/commit/1632eb975f1f31e54ca435a1b8214acedde27711))
* **conf/about:** Rename __init__.yaml to entelecheia.yaml ([`e37a295`](https://github.com/entelecheia/entelecheia/commit/e37a29565ca8b105d82c8a485f716f7e6fc6de66))

## v0.2.13 (2023-07-22)
### Fix
* **entelecheia:** Add new config.yaml file ([`ec7704e`](https://github.com/entelecheia/entelecheia/commit/ec7704e067c3114394a390710840c9b599a55409))
* **dependencies:** Upgrade hyfi to 1.6.1 ([`62b995c`](https://github.com/entelecheia/entelecheia/commit/62b995c784e50daa6112ab40bdeaeea4162b85ce))

## v0.2.12 (2023-07-22)
### Fix
* **dependencies:** Upgrade hyfi to 1.6.0 ([`f43ce55`](https://github.com/entelecheia/entelecheia/commit/f43ce55c04468ce6ae20f1c6eb28988f9bb4f8ca))

## v0.2.11 (2023-07-20)
### Fix
* **HyFI:** Initialize logger, modify get_version docstring ([`6b89139`](https://github.com/entelecheia/entelecheia/commit/6b8913993e5ad96f94912f131b7352b3dad11c00))
* **dependencies:** Upgrade hyfi to 1.3.1 ([`1be70c3`](https://github.com/entelecheia/entelecheia/commit/1be70c39c0f86f3303c8a40bf3204fafd9aca542))

## v0.2.10 (2023-07-18)
### Fix
* **dependencies:** Upgrade hyfi to 1.2.14, remove test files ([`32ce923`](https://github.com/entelecheia/entelecheia/commit/32ce9234b034a35fd65ac03f584c3640ca334071))

## v0.2.9 (2023-07-17)
### Fix
* **dependencies:** Upgrade hyfi to 1.2.13 ([`a4f107b`](https://github.com/entelecheia/entelecheia/commit/a4f107bae69b0e83626ddc885bd0ecbd73080c6c))

## v0.2.8 (2023-07-17)
### Fix
* **dependencies:** Upgrade hyfi to 1.2.11 ([`e3a71d5`](https://github.com/entelecheia/entelecheia/commit/e3a71d532fe8f952db851030282e573e5bb9cfd6))

## v0.2.7 (2023-07-16)
### Fix
* **dependencies:** Upgrade hyfi to 1.2.10 ([`210281e`](https://github.com/entelecheia/entelecheia/commit/210281e7a789b5f6843e8ff888ac77e1857aeed1))

## v0.2.6 (2023-07-04)
### Fix
* **dependencies:** Upgrade hyfi to 1.0.2 ([`e6a95da`](https://github.com/entelecheia/entelecheia/commit/e6a95da6a9826302e8045e30f57cf67ee330482b))

## v0.2.5 (2023-07-04)
### Fix
* **dependencies:** Upgrade hyfi to 1.0.0 ([`688ac62`](https://github.com/entelecheia/entelecheia/commit/688ac6268a09da40eb073a7b53435af490635e18))

## v0.2.4 (2023-06-27)
### Fix
* **dependencies:** Upgrade hyfi to 0.15.0 ([`1bdcaa3`](https://github.com/entelecheia/entelecheia/commit/1bdcaa3d182ea69c8653aa55f5739f8a0524dcf5))

## v0.2.3 (2023-06-21)
### Fix
* **template:** Apply the latest template ([`ff9a73e`](https://github.com/entelecheia/entelecheia/commit/ff9a73e932ce704ad91f2fe8a7e488e5d57092cd))

## v0.2.2 (2023-06-14)
### Fix
* **hyfi-conf:** Update hyfi configs to the latest ([`22ba27c`](https://github.com/entelecheia/entelecheia/commit/22ba27c223a4040d8186ceefffcb0048f1bc3c7e))

## v0.2.1 (2023-06-06)
### Fix
* Update the template ([`44c4de9`](https://github.com/entelecheia/entelecheia/commit/44c4de946ed16210b6b55da1d3450dc2dba2842a))

## v0.2.0 (2023-05-05)
### Feature
* Apply updated template ([`0fc6434`](https://github.com/entelecheia/entelecheia/commit/0fc6434aa5d3ca49ecb888e614070e8abb9f3501))

## v0.1.4 (2023-04-26)
### Fix
* Apply updated template ([`2679928`](https://github.com/entelecheia/entelecheia/commit/2679928d0a8702546fd491b94e16bca3f8fea363))
